RealmDebuggerClient class

A Live, Real-Time Read-Only (and Write-Capable) Database Debugger Client for Flutter applications using MongoDB Realm.

Connects your active Realm instance directly to the realm-debugger dashboard over WebSockets.

Constructors

RealmDebuggerClient(Realm realm, {String serverUrl = 'ws://localhost:5000'})

Properties

hashCode int
The hash code for this object.
no setterinherited
realm → Realm
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverUrl String
final

Methods

dispose() → void
Closes the connection and cancels all database subscriptions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
Connects to the WebSocket server and starts streaming database changes.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited